@@ -23,7 +23,7 @@ excel.warnings.simplefilter('ignore')
 
 ROOT_DIR = Path(__file__).parent
 TEMPLATE_XLS = ROOT_DIR.joinpath('template', 'case.xlsm')
-TAPD_BASE_URL = 'http://9.134.187.9:8080'
+TAPD_BASE_URL = 'http://9.134.187.9'
 
 BVT_TASK_TEMPLATE = ROOT_DIR.joinpath('template', 'bvt_task.html')
 
